if (!require (ts, quietly=TRUE))
  stop ("Package ts is needed. Stopping")
M1 <- ts(c(
450.9,
453.0,
459.1,
464.6,
469.6,
473.1,
474.6,
474.3,
475.4,
472.9,
468.7,
467.5,
464.7,
461.2,
457.1,
453.0,
447.5,
449.6,
454.2,
458.5,
464.1,
466.3,
468.1,
460.0,
459.2,
455.7,
459.5,
455.9,
458.0,
461.5,
462.2,
465.4,
467.4,
468.5,
466.5,
467.7,
471.9,
474.8,
477.7,
479.9,
481.9,
484.8,
491.3,
495.6,
498.3,
497.6,
501.7,
507.8,
511.8,
511.8,
506.2,
503.1,
507.1,
510.8,
518.0,
521.3,
521.9,
525.4,
528.3,
533.8,
536.5,
532.8,
527.6,
523.2,
521.4,
518.1,
519.4,
521.2,
524.7,
530.8,
534.1,
536.5,
542.6,
547.8,
554.4,
562.5,
565.2,
560.1,
556.1,
548.5,
542.1,
532.8,
522.8,
511.9,
505.3,
506.8,
505.5,
501.0,
502.2,
505.5,
502.6,
505.3,
508.1,
507.7,
509.4,
513.0,
513.7,
514.1,
512.5,
509.7,
503.3,
496.1,
497.2,
487.6,
474.0,
451.2,
464.9,
465.3,
455.3,
453.7,
448.9,
447.1,
451.2,
447.1,
449.1,
464.9,
475.8,
484.3,
493.6,
496.4,
497.5,
500.4,
501.5,
502.2,
511.0,
518.2,
533.9,
543.2,
553.4,
576.8,
598.0,
620.0,
631.9,
634.8,
630.1,
630.5),
start=c(1954,1), end=c(1987,4), frequency=4)
GNP <- ts(c(
1406.8,
1401.2,
1418.0,
1438.8,
1469.6,
1485.7,
1505.5,
1518.7,
1515.7,
1522.6,
1523.7,
1540.6,
1553.3,
1552.4,
1561.5,
1537.3,
1506.1,
1514.2,
1550.0,
1586.7,
1606.4,
1637.0,
1629.5,
1643.4,
1671.6,
1666.8,
1668.4,
1654.1,
1671.3,
1692.1,
1716.3,
1754.9,
1777.9,
1796.4,
1813.1,
1810.1,
1834.6,
1860.0,
1892.5,
1906.1,
1948.7,
1965.4,
1985.2,
1993.7,
2036.9,
2066.4,
2099.3,
2147.6,
2190.1,
2195.8,
2218.3,
2229.2,
2241.8,
2255.2,
2287.7,
2300.6,
2327.3,
2366.9,
2385.3,
2383.0,
2416.5,
2419.8,
2433.2,
2423.5,
2408.6,
2406.5,
2435.8,
2413.8,
2478.6,
2478.4,
2491.1,
2491.0,
2545.6,
2595.1,
2622.1,
2671.3,
2734.0,
2741.0,
2738.3,
2762.8,
2747.4,
2755.2,
2719.3,
2695.4,
2642.7,
2669.6,
2714.9,
2752.7,
2804.4,
2816.9,
2828.6,
2856.8,
2896.0,
2942.7,
3001.8,
2994.1,
3020.5,
3115.9,
3142.6,
3181.6,
3181.7,
3178.9,
3207.4,
3201.3,
3233.4,
3157.0,
3159.1,
3199.2,
3261.1,
3250.2,
3264.6,
3219.3,
3170.4,
3179.9,
3154.5,
3159.3,
3186.6,
3258.3,
3306.4,
3365.1,
3451.7,
3498.0,
3520.6,
3535.2,
3577.5,
3599.2,
3635.8,
3662.4,
3719.3,
3711.6,
3721.3,
3734.7,
3776.7,
3823.0,
3865.3,
3923.0),
start=c(1954,1), end=c(1987,4), frequency=4)
rs <- ts(c(
0.010800000,
0.0081333333,
0.0087000000,
0.010366667,
0.012600000,
0.015133333,
0.018633333,
0.023466667,
0.023800000,
0.025966667,
0.025966667,
0.030633333,
0.031700000,
0.031566667,
0.033800000,
0.033433333,
0.018366667,
0.010200000,
0.017100000,
0.027866667,
0.028000000,
0.030200000,
0.035333333,
0.043000000,
0.039433333,
0.030900000,
0.023933333,
0.023600000,
0.023766667,
0.023266667,
0.023233333,
0.024766667,
0.027400000,
0.027166667,
0.028566667,
0.028033333,
0.029100000,
0.029433333,
0.032800000,
0.034966667,
0.035366667,
0.034800000,
0.035066667,
0.036866667,
0.039000000,
0.038800000,
0.038600000,
0.041566667,
0.046333333,
0.045966667,
0.050500000,
0.045800000,
0.045266667,
0.036566667,
0.043466667,
0.047866667,
0.050633333,
0.055066667,
0.052266667,
0.055800000,
0.061400000,
0.062400000,
0.070466667,
0.073166667,
0.072600000,
0.067533333,
0.063833333,
0.053600000,
0.038600000,
0.042066667,
0.050500000,
0.042333333,
0.034333333,
0.037466667,
0.042400000,
0.048500000,
0.056400000,
0.066100000,
0.083900000,
0.074633333,
0.076033333,
0.082666667,
0.082833333,
0.073333333,
0.058700000,
0.054000000,
0.063333333,
0.056833333,
0.049533333,
0.051666667,
0.051700000,
0.046966667,
0.046233333,
0.048266667,
0.054733333,
0.061366667,
0.064100000,
0.064833333,
0.073166667,
0.086800000,
0.093600000,
0.093733333,
0.096300000,
0.11803333,
0.13460000,
0.10050000,
0.092366667,
0.13710000,
0.14366667,
0.14830000,
0.15086667,
0.12023333,
0.12893333,
0.12360000,
0.097066667,
0.079333333,
0.080800000,
0.084200000,
0.091866667,
0.087933333,
0.091333333,
0.098433333,
0.10343333,
0.089733333,
0.081833333,
0.075233333,
0.071033333,
0.071466667,
0.068866667,
0.061300000,
0.055333333,
0.053400000,
0.055333333,
0.057333333,
0.060333333,
0.060033333),
start=c(1954,1), end=c(1987,4), frequency=4)
rl <- ts(c(
0.026133333,
0.025233333,
0.024900000,
0.025666667,
0.027466667,
0.028166667,
0.029266667,
0.028900000,
0.028866667,
0.029900000,
0.031266667,
0.033000000,
0.032733333,
0.034333333,
0.036300000,
0.035333333,
0.032566667,
0.031533333,
0.035700000,
0.037533333,
0.039166667,
0.040600000,
0.041566667,
0.041666667,
0.042233333,
0.041066667,
0.038300000,
0.039066667,
0.038266667,
0.038033333,
0.039733333,
0.040066667,
0.040600000,
0.038900000,
0.039800000,
0.038766667,
0.039133333,
0.039800000,
0.040133333,
0.041066667,
0.041566667,
0.041633333,
0.041433333,
0.041400000,
0.041500000,
0.041433333,
0.041966667,
0.043500000,
0.045566667,
0.045833333,
0.047800000,
0.046966667,
0.044400000,
0.047100000,
0.049333333,
0.053300000,
0.052433333,
0.053033333,
0.050733333,
0.054200000,
0.058833333,
0.059133333,
0.061366667,
0.065333333,
0.065633333,
0.068200000,
0.066500000,
0.062666667,
0.058233333,
0.058833333,
0.057500000,
0.055200000,
0.056500000,
0.056566667,
0.056266667,
0.056100000,
0.061000000,
0.062266667,
0.065966667,
0.063000000,
0.066366667,
0.070500000,
0.072700000,
0.069733333,
0.067033333,
0.069733333,
0.070933333,
0.072233333,
0.069100000,
0.068866667,
0.067900000,
0.065500000,
0.070133333,
0.070966667,
0.069766667,
0.071600000,
0.075800000,
0.078500000,
0.079333333,
0.081966667,
0.084366667,
0.084366667,
0.084833333,
0.096066667,
0.11150000,
0.10016667,
0.10433333,
0.11640000,
0.12010000,
0.12656667,
0.13600000,
0.13230000,
0.13446667,
0.12943333,
0.12200000,
0.10340000,
0.10436667,
0.10346667,
0.11260000,
0.11323333,
0.11543333,
0.12686667,
0.12340000,
0.11373333,
0.11426667,
0.10913333,
0.10590000,
0.10080000,
0.089033333,
0.079466667,
0.078866667,
0.078400000,
0.076366667,
0.085766667,
0.090833333,
0.092400000),
start=c(1954,1), end=c(1987,4), frequency=4)
USeconomic <- ts.union (log(M1), log(GNP), rs, rl)
